==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/ExponentialDelayHttpDelayTypeFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import me.snowdrop.istio.api.DurationFluentImpl;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.JsonDeserializer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import java.lang.Override;
import com.fasterxml.jackson.core.JsonParser;
import me.snowdrop.istio.api.Duration;
import java.lang.Integer;
import javax.validation.Valid;
import java.lang.Long;
import java.lang.Object;
import me.snowdrop.istio.api.DurationBuilder;

public class ExponentialDelayHttpDelayTypeFluentImpl<A extends ExponentialDelayHttpDelayTypeFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ExponentialDelayHttpDelayTypeFluent<A>{

    private DurationBuilder exponentialDelay;

    public ExponentialDelayHttpDelayTypeFluentImpl(){
    }
    public ExponentialDelayHttpDelayTypeFluentImpl(ExponentialDelayHttpDelayType instance){
            this.withExponentialDelay(instance.getExponentialDelay()); 
    }

    
/**
 * This method has been deprecated, please use method buildExponentialDelay instead.
 * @return The buildable object.
 */
@Deprecated public Duration getExponentialDelay(){
            return this.exponentialDelay!=null?this.exponentialDelay.build():null;
    }

    public Duration buildExponentialDelay(){
            return this.exponentialDelay!=null?this.exponentialDelay.build():null;
    }

    public A withExponentialDelay(Duration exponentialDelay){
            _visitables.remove(this.exponentialDelay);
            if (exponentialDelay!=null){ this.exponentialDelay= new DurationBuilder(exponentialDelay); _visitables.add(this.exponentialDelay);} return (A) this;
    }

    public Boolean hasExponentialDelay(){
            return this.exponentialDelay != null;
    }

    public A withNewExponentialDelay(Integer nanos,Long seconds){
            return (A)withExponentialDelay(new Duration(nanos, seconds));
    }

    public ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<A> withNewExponentialDelay(){
            return new ExponentialDelayNestedImpl();
    }

    public ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<A> withNewExponentialDelayLike(Duration item){
            return new ExponentialDelayNestedImpl(item);
    }

    public ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<A> editExponentialDelay(){
            return withNewExponentialDelayLike(getExponentialDelay());
    }

    public ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<A> editOrNewExponentialDelay(){
            return withNewExponentialDelayLike(getExponentialDelay() != null ? getExponentialDelay(): new DurationBuilder().build());
    }

    public ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<A> editOrNewExponentialDelayLike(Duration item){
            return withNewExponentialDelayLike(getExponentialDelay() != null ? getExponentialDelay(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExponentialDelayHttpDelayTypeFluentImpl that = (ExponentialDelayHttpDelayTypeFluentImpl) o;
            if (exponentialDelay != null ? !exponentialDelay.equals(that.exponentialDelay) :that.exponentialDelay != null) return false;
            return true;
    }


    public class ExponentialDelayNestedImpl<N> extends DurationFluentImpl<ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<N>> implements ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final DurationBuilder builder;
    
            ExponentialDelayNestedImpl(Duration item){
                    this.builder = new DurationBuilder(this, item);
            }
            ExponentialDelayNestedImpl(){
                    this.builder = new DurationBuilder(this);
            }
    
    public N and(){
            return (N) ExponentialDelayHttpDelayTypeFluentImpl.this.withExponentialDelay(builder.build());
    }
    public N endExponentialDelay(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/ExponentialDelayHttpDelayTypeFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import me.snowdrop.istio.api.DurationFluentImpl;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.JsonDeserializer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import java.lang.Override;
import com.fasterxml.jackson.core.JsonParser;
import me.snowdrop.istio.api.Duration;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Object;
import me.snowdrop.istio.api.DurationBuilder;

public class ExponentialDelayHttpDelayTypeFluentImpl<A extends ExponentialDelayHttpDelayTypeFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ExponentialDelayHttpDelayTypeFluent<A>{

    private DurationBuilder exponentialDelay;

    public ExponentialDelayHttpDelayTypeFluentImpl(){
    }
    public ExponentialDelayHttpDelayTypeFluentImpl(ExponentialDelayHttpDelayType instance){
            this.withExponentialDelay(instance.getExponentialDelay()); 
    }

    
/**
 * This method has been deprecated, please use method buildExponentialDelay instead.
 * @return The buildable object.
 */
@Deprecated public Duration getExponentialDelay(){
            return this.exponentialDelay!=null?this.exponentialDelay.build():null;
    }

    public Duration buildExponentialDelay(){
            return this.exponentialDelay!=null?this.exponentialDelay.build():null;
    }

    public A withExponentialDelay(Duration exponentialDelay){
            _visitables.get("exponentialDelay").remove(this.exponentialDelay);
            if (exponentialDelay!=null){ this.exponentialDelay= new DurationBuilder(exponentialDelay); _visitables.get("exponentialDelay").add(this.exponentialDelay);} return (A) this;
    }

    public Boolean hasExponentialDelay(){
            return this.exponentialDelay != null;
    }

    public A withNewExponentialDelay(Integer nanos,Long seconds){
            return (A)withExponentialDelay(new Duration(nanos, seconds));
    }

    public ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<A> withNewExponentialDelay(){
            return new ExponentialDelayNestedImpl();
    }

    public ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<A> withNewExponentialDelayLike(Duration item){
            return new ExponentialDelayNestedImpl(item);
    }

    public ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<A> editExponentialDelay(){
            return withNewExponentialDelayLike(getExponentialDelay());
    }

    public ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<A> editOrNewExponentialDelay(){
            return withNewExponentialDelayLike(getExponentialDelay() != null ? getExponentialDelay(): new DurationBuilder().build());
    }

    public ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<A> editOrNewExponentialDelayLike(Duration item){
            return withNewExponentialDelayLike(getExponentialDelay() != null ? getExponentialDelay(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ExponentialDelayHttpDelayTypeFluentImpl that = (ExponentialDelayHttpDelayTypeFluentImpl) o;
            if (exponentialDelay != null ? !exponentialDelay.equals(that.exponentialDelay) :that.exponentialDelay != null) return false;
            return true;
    }


    public class ExponentialDelayNestedImpl<N> extends DurationFluentImpl<ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<N>> implements ExponentialDelayHttpDelayTypeFluent.ExponentialDelayNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final DurationBuilder builder;
    
            ExponentialDelayNestedImpl(Duration item){
                    this.builder = new DurationBuilder(this, item);
            }
            ExponentialDelayNestedImpl(){
                    this.builder = new DurationBuilder(this);
            }
    
    public N and(){
            return (N) ExponentialDelayHttpDelayTypeFluentImpl.this.withExponentialDelay(builder.build());
    }
    public N endExponentialDelay(){
            return and();
    }

}


}
